
import { getUTCTime } from '@/utils';
import * as React from 'react';
import './style.less';
export interface  CountdownProps {
  isUtc: boolean,
  style: object,// 容器样式
  nowTime: number,
  endTime: number,
  isShowDay: boolean,
  subStyle: object,
  timeStyle: object,
  textStyle: object,

  daysText: string,
  hoursText: string,
  minsText: string,
  secsText: string,
}


const Countdown: React.FC<CountdownProps>  = (props) => {
  let { isShowDay, nowTime, endTime, isUtc, style, subStyle} = props;
  if(isUtc) {
    nowTime = nowTime || getUTCTime()
  } else {
    nowTime = new Date().getTime();
  }
  const ref = React.useRef<any>({});
  ref.current.nowTime = nowTime;
  const [time, setTime] = React.useState({
    days: '00',
    hours: '00',
    mins: '00',
    secs: '00',
  });
  const tick = () => {
    let nowTime = ref.current.nowTime;
    let curEndTime = endTime || 0;
    const diff = parseInt(((curEndTime - nowTime)/ 1000).toString());
    if (diff < 0) {
      clearInterval(ref?.current?.timerId)
      return;
    }
    let days = parseInt((diff / 60 / 60 / 24).toString())
    let hours = parseInt((diff / 60 / 60 % 24).toString())
    let mins = parseInt((diff/ 60 % 60).toString())
    let secs = parseInt((diff % 60).toString())
    const times = ({
      days: days.toString().padStart(2, '0'),
      hours: hours.toString().padStart(2, '0'),
      mins: mins.toString().padStart(2, '0'),
      secs: secs.toString().padStart(2, '0'),
    })
    ref.current.nowTime = nowTime + 1000;
    setTime(times)
  }
  React.useEffect(() => {
    let timerId = setInterval(() => tick(), 1000);
    ref.current.timerId = timerId;
    return () => clearInterval(timerId);
  }, [endTime]);
  const newSubStyle: React.CSSProperties = {
    ...subStyle,
    textAlign: 'center',
  };
  return <React.Fragment>
      <div style={{
        display: 'flex',
        alignItems: 'center',
        justifyContent: 'center',
        ...style
      }}>
        {isShowDay && 
          <div style={newSubStyle} >
            <div style={props?.timeStyle}>{time.days}</div>
            <div style={props?.textStyle}>{props.daysText}</div>
          </div>
        }
        <div style={newSubStyle}>
           <div style={props?.timeStyle}>{time.hours}</div>
           <div style={props?.textStyle}>{props.hoursText}</div>
        </div>
        <div style={newSubStyle}>
           <div style={props?.timeStyle}>{time.mins}</div>
           <div style={props?.textStyle}>{props.minsText}</div>
        </div>
        <div style={newSubStyle}>
           <div style={props?.timeStyle}>{time.secs}</div>
           <div style={props?.textStyle}>{props.secsText}</div>
        </div>
      </div>
  </React.Fragment>
}
Countdown.displayName = 'Countdown';
Countdown.defaultProps = {
  isShowDay: true,
  isUtc: true,
  daysText: 'Days',
  hoursText: 'Hours',
  minsText: 'Mins',
  secsText: 'Secs'
}
export default Countdown;